@@ -140,7 +140,7 @@ def scan_nll(input_file:str, poi_min:float, poi_max:float, poi_step:float, poi:s
         results = common_utils.parallel_run(evaluate_nll, *arguments, max_workers=max_workers)
     else:
         results = []
-        for point, uncond, outname_ in zip(points, uncondistional, outnames):
+        for point, uncond, outname_ in zip(points, unconditional, outnames):
             nll = evaluate_nll(input_file, point, poi, vmin, vmax, uncond, workspace, model_config, data,
                                snapshot, profile, fix, hesse, minos, constrain, minimizer_type, minimizer_algo,
                                num_cpu, binned, eps, strategy, fix_cache, fix_multi, mpsplit, max_calls,
